@@ -56,6 +56,8 @@
 
 #include <Sonnet/DictionaryComboBox>
 
+#include "invite-contact-dialog.h"
+
 #define PREFERRED_TEXTCHAT_HANDLER "org.freedesktop.Telepathy.Client.KTp.TextUi"
 #define PREFERRED_FILETRANSFER_HANDLER "org.freedesktop.Telepathy.Client.KTp.FileTransfer"
 #define PREFERRED_AUDIO_VIDEO_HANDLER "org.freedesktop.Telepathy.Client.KTp.CallUi"
@@ -310,8 +312,7 @@ void ChatWindow::onCurrentIndexChanged(int index)
         setFileTransferEnabled(selfCapabilities.fileTransfers() && contactCapabilites.fileTransfers());
         setVideoCallEnabled(selfCapabilities.streamedMediaVideoCalls() && contactCapabilites.streamedMediaVideoCalls());
         setShareDesktopEnabled(s_krfbAvailableChecker->isAvailable() && contactCapabilites.streamTubes(QLatin1String("rfb")));
-        /// TODO re-activate check when invitation to chat has been sorted out
-        setInviteToChatEnabled(false);
+        setInviteToChatEnabled(true);
 
         toggleBlockButton(currentChatTab->textChannel()->targetContact()->isBlocked());
 
@@ -320,8 +321,7 @@ void ChatWindow::onCurrentIndexChanged(int index)
         setFileTransferEnabled(false);
         setVideoCallEnabled(false);
         setShareDesktopEnabled(false);
-        /// TODO re-activate check when invitation to chat has been sorted out
-        setInviteToChatEnabled(false);
+        setInviteToChatEnabled(true);
         setBlockEnabled(false);
 
     }
@@ -386,7 +386,10 @@ void ChatWindow::onGenericOperationFinished(Tp::PendingOperation* op)
 
 void ChatWindow::onInviteToChatTriggered()
 {
-    /// TODO
+    ChatTab *currChat = qobject_cast<ChatTab*>(m_tabWidget->currentWidget());
+    InviteContactDialog *dialog = new InviteContactDialog(currChat->account(), currChat->textChannel(), this);
+    dialog->setAttribute(Qt::WA_DeleteOnClose);
+    dialog->show();
 }
 
 void ChatWindow::onNextTabActionTriggered()
@@ -512,6 +515,7 @@ void ChatWindow::showSettingsDialog()
 
     dialog->addModule(QLatin1String("kcm_ktp_chat_appearance"));
     dialog->addModule(QLatin1String("kcm_ktp_chat_behavior"));
+    dialog->addModule(QLatin1String("kcm_ktp_chat_messages"));
 
     dialog->setAttribute(Qt::WA_DeleteOnClose);
     dialog->show();
@@ -584,7 +588,7 @@ void ChatWindow::setupCustomActions()
     connect(fileTransferAction, SIGNAL(triggered()), this, SLOT(onFileTransferTriggered()));
 
     KAction *inviteToChat = new KAction(KIcon(QLatin1String("user-group-new")), i18n("&Invite to Chat"), this);
-    inviteToChat->setToolTip(i18nc("Toolbar icon tooltip", "Invite any other contacts to join this chat"));
+    inviteToChat->setToolTip(i18nc("Toolbar icon tooltip", "Invite another contact to join this chat"));
     connect(inviteToChat, SIGNAL(triggered()), this, SLOT(onInviteToChatTriggered()));
 
     KAction *videoCallAction = new KAction(KIcon(QLatin1String("camera-web")), i18n("&Video Call"), this);
@@ -606,7 +610,7 @@ void ChatWindow::setupCustomActions()
     spellDictComboAction->setIconText(i18n("Choose Spelling Language"));
 
 #ifdef TELEPATHY_LOGGER_QT4_FOUND
-    KAction *openLogAction = new KAction(KIcon(QLatin1String("view-pim-journal")), i18nc("Action to open the log viwer with a specified contact","&Previous conversations"), this);
+    KAction *openLogAction = new KAction(KIcon(QLatin1String("view-pim-journal")), i18nc("Action to open the log viewer with a specified contact","&Previous Conversations"), this);
     connect(openLogAction, SIGNAL(triggered()), SLOT(onOpenLogTriggered()));
 #endif
 
