@@ -37,6 +37,8 @@
 #include <KDebug>
 #include <KColorScheme>
 #include <KLineEdit>
+#include <KMimeType>
+#include <KTemporaryFile>
 
 #include <TelepathyQt/Account>
 #include <TelepathyQt/Message>
@@ -44,6 +46,8 @@
 #include <TelepathyQt/AvatarData>
 #include <TelepathyQt/Connection>
 #include <TelepathyQt/Presence>
+#include <TelepathyQt/PendingChannelRequest>
+#include <TelepathyQt/OutgoingFileTransferChannel>
 
 #include <KTp/presence.h>
 #include "message-processor.h"
@@ -71,6 +75,8 @@ public:
     LogManager *logManager;
     QTimer *pausedStateTimer;
 
+    QList< Tp::OutgoingFileTransferChannelPtr > tmpFileTransfers;
+
     KComponentData telepathyComponentData();
 };
 
@@ -128,6 +134,10 @@ ChatWidget::ChatWidget(const Tp::TextChannelPtr & channel, const Tp::AccountPtr
 
     d->ui.chatArea->load((d->isGroupChat?AdiumThemeView::GroupChat:AdiumThemeView::SingleUserChat));
 
+    d->ui.sendMessageBox->setAcceptDrops(false);
+    d->ui.chatArea->setAcceptDrops(false);
+    setAcceptDrops(true);
+
     AdiumThemeHeaderInfo info;
 
     info.setGroupChat(d->isGroupChat);
@@ -242,7 +252,7 @@ Tp::AccountPtr ChatWidget::account() const
 
 KIcon ChatWidget::icon() const
 {
-    if (d->channel->connection()->status() == Tp::ConnectionStatusConnected) {
+    if (d->account->currentPresence() != Tp::Presence::offline()) {
         //normal chat - self and one other person.
         if (!d->isGroupChat) {
             //find the other contact which isn't self.
@@ -277,25 +287,16 @@ ChatSearchBar *ChatWidget::chatSearchBar() const
 
 void ChatWidget::setChatEnabled(bool enable)
 {
+    d->ui.contactsView->setEnabled(enable);
     d->ui.sendMessageBox->setEnabled(enable);
-
-    // show a message informing the user
-    AdiumThemeStatusInfo statusMessage;
-
-    if (!enable) {
-        statusMessage.setMessage(i18n("Connection closed"));
-    } else {
-        statusMessage.setMessage(i18nc("Connected to IM service", "Connected"));
-    }
-    statusMessage.setService(d->channel->connection()->protocolName());
-    statusMessage.setTime(QDateTime::currentDateTime());
-    d->ui.chatArea->addStatusMessage(statusMessage);
-
     Q_EMIT iconChanged(icon());
 }
 
 void ChatWidget::setTextChannel(const Tp::TextChannelPtr &newTextChannelPtr)
 {
+    if (!d->channel.isNull()) {
+        onChannelConnectionChanged(newTextChannelPtr->connection()->status());
+    }
     d->channel = newTextChannelPtr;     // set the new channel
     d->contactModel->setTextChannel(newTextChannelPtr);
 
@@ -329,6 +330,110 @@ void ChatWidget::keyPressEvent(QKeyEvent *e)
     QWidget::keyPressEvent(e);
 }
 
+void ChatWidget::temporaryFileTransferStateChanged(Tp::FileTransferState state, Tp::FileTransferStateChangeReason reason)
+{
+    Q_UNUSED(reason);
+
+    if ((state == Tp::FileTransferStateCompleted) || (state == Tp::FileTransferStateCancelled)) {
+        Tp::OutgoingFileTransferChannel *channel = qobject_cast<Tp::OutgoingFileTransferChannel*>(sender());
+        Q_ASSERT(channel);
+
+        QString localFile = QUrl(channel->uri()).toLocalFile();
+        if (QFile::exists(localFile)) {
+            QFile::remove(localFile);
+            kDebug() << "File" << localFile << "removed";
+        }
+
+        d->tmpFileTransfers.removeAll(Tp::OutgoingFileTransferChannelPtr(channel));
+    }
+}
+
+
+void ChatWidget::temporaryFileTransferChannelCreated(Tp::PendingOperation *operation)
+{
+    Tp::PendingChannelRequest *request = qobject_cast<Tp::PendingChannelRequest*>(operation);
+    Q_ASSERT(request);
+
+    Tp::OutgoingFileTransferChannelPtr transferChannel;
+    transferChannel = Tp::OutgoingFileTransferChannelPtr::qObjectCast<Tp::Channel>(request->channelRequest()->channel());
+    Q_ASSERT(!transferChannel.isNull());
+
+    /* Make sure the pointer lives until the transfer is over
+     * so that the signal connection below lasts until the end */
+    d->tmpFileTransfers << transferChannel;
+
+    connect(transferChannel.data(), SIGNAL(stateChanged(Tp::FileTransferState,Tp::FileTransferStateChangeReason)),
+            this, SLOT(temporaryFileTransferStateChanged(Tp::FileTransferState,Tp::FileTransferStateChangeReason)));
+}
+
+
+void ChatWidget::dropEvent(QDropEvent *e)
+{
+    const QMimeData *data = e->mimeData();
+
+    if (data->hasUrls()) {
+        Q_FOREACH(const QUrl &url, data->urls()) {
+            if (url.isLocalFile()) {
+                Tp::FileTransferChannelCreationProperties properties(
+                        url.toLocalFile(),
+                        KMimeType::findByFileContent(url.toLocalFile())->name());
+                d->account->createFileTransfer(d->channel->targetContact(),
+                        properties, QDateTime::currentDateTime(),
+                        QLatin1String("org.freedesktop.Telepathy.Client.KTp.FileTransfer"));
+            } else {
+                d->ui.sendMessageBox->append(url.toString());
+            }
+        }
+        e->acceptProposedAction();
+    } else if (data->hasText()) {
+        d->ui.sendMessageBox->append(data->text());
+        e->acceptProposedAction();
+    } else if (data->hasHtml()) {
+        d->ui.sendMessageBox->insertHtml(data->html());
+        e->acceptProposedAction();
+    } else if (data->hasImage()) {
+        QImage image = qvariant_cast<QImage>(data->imageData());
+
+        KTemporaryFile tmpFile;
+        tmpFile.setPrefix(d->account->displayName() + QLatin1String("-"));
+        tmpFile.setSuffix(QLatin1String(".png"));
+        tmpFile.setAutoRemove(false);
+        if (!tmpFile.open()) {
+            return;
+        }
+        tmpFile.close();
+
+        if (!image.save(tmpFile.fileName(), "PNG")) {
+            return;
+        }
+
+        Tp::FileTransferChannelCreationProperties properties(
+                    tmpFile.fileName(),
+                    KMimeType::findByFileContent(tmpFile.fileName())->name());
+        Tp::PendingChannelRequest *request;
+        request = d->account->createFileTransfer(d->channel->targetContact(),
+                        properties, QDateTime::currentDateTime(),
+                        QLatin1String("org.freedesktop.Telepathy.Client.KTp.FileTransfer"));
+        connect(request, SIGNAL(finished(Tp::PendingOperation*)),
+                this, SLOT(temporaryFileTransferChannelCreated(Tp::PendingOperation*)));
+
+        kDebug() << "Starting transfer of" << tmpFile.fileName();
+        e->acceptProposedAction();
+    }
+
+    QWidget::dropEvent(e);
+}
+
+void ChatWidget::dragEnterEvent(QDragEnterEvent *e)
+{
+    if (e->mimeData()->hasHtml() || e->mimeData()->hasImage() ||
+        e->mimeData()->hasText() || e->mimeData()->hasUrls()) {
+            e->accept();
+    }
+
+    QWidget::dragEnterEvent(e);
+}
+
 QString ChatWidget::title() const
 {
     return d->title;
@@ -394,6 +499,8 @@ void ChatWidget::setupChannelSignals()
             SLOT(onChatStatusChanged(Tp::ContactPtr,Tp::ChannelChatState)));
     connect(d->channel.data(), SIGNAL(invalidated(Tp::DBusProxy*,QString,QString)),
             this, SLOT(onChannelInvalidated()));
+    connect(d->channel.data()->connection().data(), SIGNAL(statusChanged(Tp::ConnectionStatus)),
+            this, SLOT(onChannelConnectionChanged(Tp::ConnectionStatus)));
 
     if (d->channel->hasChatStateInterface()) {
         connect(d->ui.sendMessageBox, SIGNAL(textChanged()), SLOT(onInputBoxChanged()));
@@ -613,11 +720,11 @@ void ChatWidget::notifyAboutIncomingMessage(const Tp::ReceivedMessage & message)
     if (message.sender() == d->channel->groupSelfContact()) {
         return;
     }
-    
+
     if (message.isDeliveryReport()) {
         return;
     }
-    
+
     // kde_telepathy_contact_highlight (contains your name)
     // kde_telepathy_info_event
 
@@ -937,4 +1044,18 @@ void ChatWidget::onChatPausedTimerExpired()
         d->channel->requestChatState(Tp::ChannelChatStatePaused);
 }
 
+void ChatWidget::onChannelConnectionChanged(Tp::ConnectionStatus status)
+{
+    if (status == Tp::ConnectionStatusConnected) {
+        onContactPresenceChange(d->channel->groupSelfContact(), KTp::Presence(d->channel->groupSelfContact()->presence()));
+    } else if (status == Tp::ConnectionStatusDisconnected) {
+        // show a message informing the user
+        AdiumThemeStatusInfo statusMessage;
+        statusMessage.setMessage(i18n("You are now offline"));
+        statusMessage.setService(d->channel->connection()->protocolName());
+        statusMessage.setTime(QDateTime::currentDateTime());
+        d->ui.chatArea->addStatusMessage(statusMessage);
+    }
+}
+
 #include "chat-widget.moc"
