@@ -103,6 +103,8 @@ protected:
     void changeEvent(QEvent *e);
     void resizeEvent(QResizeEvent *);
     void keyPressEvent(QKeyEvent *e);
+    virtual void dropEvent(QDropEvent *e);
+    virtual void dragEnterEvent(QDragEnterEvent *e);
 
 protected Q_SLOTS:
     /** Show the received message in the chat window*/
@@ -133,6 +135,8 @@ protected Q_SLOTS:
 
     void chatViewReady();
 
+    void onChannelConnectionChanged(Tp::ConnectionStatus status);
+
 Q_SIGNALS:
     /** Emitted whenever the title for the chat changes, normally the name of the contact or a topic*/
     void titleChanged(const QString &title);
@@ -168,6 +172,9 @@ private Q_SLOTS:
     void onHistoryFetched(const QList<AdiumThemeContentInfo> &messages);
     void onChatPausedTimerExpired();
 
+    void temporaryFileTransferChannelCreated(Tp::PendingOperation *operation);
+    void temporaryFileTransferStateChanged(Tp::FileTransferState, Tp::FileTransferStateChangeReason);
+
 private:
     /** connects necessary signals for the channel */
     void setupChannelSignals();
